CSSBackgroundSize class

Constructors

CSSBackgroundSize({required BoxFit fit, CSSLengthValue? width, CSSLengthValue? height})

Properties

fit ↔ BoxFit
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ CSSLengthValue?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ CSSLengthValue?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited