CSSBorderRadiusMixin mixin

Superclass constraints
Mixin applications

Properties

alignContent → AlignContent
no setterinherited
alignItems → AlignItems
no setterinherited
alignSelf → AlignSelf
no setterinherited
backgroundColor → Color?
no setterinherited
backgroundImage → CSSBackgroundImage?
no setterinherited
backgroundPositionX → CSSBackgroundPosition
no setterinherited
backgroundPositionY → CSSBackgroundPosition
no setterinherited
backgroundRepeat → ImageRepeat
no setterinherited
border → EdgeInsets
no setterinherited
borderBottomColor → Color
no setterinherited
borderBottomLeftRadius ↔ CSSBorderRadius
getter/setter pairoverride-getter
borderBottomRightRadius ↔ CSSBorderRadius
getter/setter pairoverride-getter
borderBottomStyle → BorderStyle
no setterinherited
borderBottomWidth → CSSLengthValue?
no setterinherited
borderBoxHeight → double?
no setterinherited
borderBoxLogicalHeight → double?
no setterinherited
borderBoxLogicalWidth → double?
no setterinherited
borderBoxWidth → double?
no setterinherited
borderLeftColor → Color
no setterinherited
borderLeftStyle → BorderStyle
no setterinherited
borderLeftWidth → CSSLengthValue?
no setterinherited
borderRadius → List<Radius>?
no setteroverride
borderRightColor → Color
no setterinherited
borderRightStyle → BorderStyle
no setterinherited
borderRightWidth → CSSLengthValue?
no setterinherited
borderSides → List<BorderSide>?
no setterinherited
borderTopColor → Color
no setterinherited
borderTopLeftRadius ↔ CSSBorderRadius
getter/setter pairoverride-getter
borderTopRightRadius ↔ CSSBorderRadius
getter/setter pairoverride-getter
borderTopStyle → BorderStyle
no setterinherited
borderTopWidth → CSSLengthValue?
no setterinherited
bottom → CSSLengthValue
no setterinherited
color → Color
no setterinherited
colorFilter → ColorFilter?
no setterinherited
contentBoxHeight → double?
no setterinherited
contentBoxLogicalHeight → double?
no setterinherited
contentBoxLogicalWidth → double?
no setterinherited
contentBoxWidth → double?
no setterinherited
contentMaxConstraintsWidth → double
no setterinherited
contentVisibility → ContentVisibility?
no setterinherited
currentColor → Color
no setterinherited
display → CSSDisplay
no setterinherited
effectiveBorderBottomWidth → CSSLengthValue
no setterinherited
effectiveBorderLeftWidth → CSSLengthValue
no setterinherited
effectiveBorderRightWidth → CSSLengthValue
no setterinherited
effectiveBorderTopWidth → CSSLengthValue
no setterinherited
effectiveDisplay → CSSDisplay
no setterinherited
effectiveOverflowX → CSSOverflowType
no setterinherited
effectiveOverflowY → CSSOverflowType
no setterinherited
filter → List<CSSFunctionalNotation>?
no setterinherited
flexBasis → CSSLengthValue?
no setterinherited
flexDirection → FlexDirection
no setterinherited
flexGrow → double
no setterinherited
flexShrink → double
no setterinherited
flexWrap → FlexWrap
no setterinherited
fontFamily → List<String>?
no setterinherited
fontSize → CSSLengthValue
no setterinherited
fontStyle → FontStyle
no setterinherited
fontWeight → FontWeight
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → CSSLengthValue
no setterinherited
imageFilter → ImageFilter?
no setterinherited
intrinsicHeight → double
no setterinherited
intrinsicRatio → double?
no setterinherited
intrinsicWidth → double
no setterinherited
isHeightStretch → bool
no setterinherited
justifyContent → JustifyContent
no setterinherited
left → CSSLengthValue
no setterinherited
letterSpacing → CSSLengthValue?
no setterinherited
lineClamp → int?
no setterinherited
lineHeight → CSSLengthValue
no setterinherited
margin → EdgeInsets
no setterinherited
marginBottom → CSSLengthValue
no setterinherited
marginLeft → CSSLengthValue
no setterinherited
marginRight → CSSLengthValue
no setterinherited
marginTop → CSSLengthValue
no setterinherited
maxHeight → CSSLengthValue
no setterinherited
maxWidth → CSSLengthValue
no setterinherited
minHeight → CSSLengthValue
no setterinherited
minWidth → CSSLengthValue
no setterinherited
objectFit → BoxFit
no setterinherited
objectPosition → Alignment
no setterinherited
opacity → double
no setterinherited
overflowX → CSSOverflowType
no setterinherited
overflowY → CSSOverflowType
no setterinherited
padding → EdgeInsets
no setterinherited
paddingBottom → CSSLengthValue
no setterinherited
paddingBoxHeight → double?
no setterinherited
paddingBoxLogicalHeight → double?
no setterinherited
paddingBoxLogicalWidth → double?
no setterinherited
paddingBoxWidth → double?
no setterinherited
paddingLeft → CSSLengthValue
no setterinherited
paddingRight → CSSLengthValue
no setterinherited
paddingTop → CSSLengthValue
no setterinherited
parent → RenderStyle?
no setterinherited
position → CSSPositionType
no setterinherited
renderBoxModel → RenderBoxModel?
no setterinherited
no setterinherited
rootFontSize → double
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<KrakenBoxShadow>?
no setterinherited
sliverDirection → Axis
no setterinherited
target → Element
no setterinherited
textAlign → TextAlign
no setterinherited
textOverflow → TextOverflow
no setterinherited
textShadow → List<Shadow>?
no setterinherited
top → CSSLengthValue
no setterinherited
transitionDelay → List<String>
no setterinherited
transitionDuration → List<String>
no setterinherited
transitionProperty → List<String>
no setterinherited
transitionTimingFunction → List<String>
no setterinherited
verticalAlign → VerticalAlign
no setterinherited
viewportSize → Size
no setterinherited
visibility → Visibility
no setterinherited
whiteSpace → WhiteSpace
no setterinherited
width → CSSLengthValue
no setterinherited
wordSpacing → CSSLengthValue?
no setterinherited
zIndex → int?
no setterinherited

Methods

addColorRelativeProperty(String propertyName) → void
inherited
addFontRelativeProperty(String propertyName) → void
inherited
addRootFontRelativeProperty(String propertyName) → void
inherited
getCSSVariable(String identifier, String propertyName) → String?
inherited
getHeightByIntrinsicRatio() → double
inherited
getProperty(String key) → dynamic
inherited
getWidthByIntrinsicRatio() → double
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAnimationProperty(String propertyName) → String?
inherited
resolveValue(String property, String present) → dynamic
Resolve the style value.
inherited
setCSSVariable(String identifier, String value) → void
inherited
toString() → String
A string representation of this object.
inherited
visitChildren<T extends RenderStyle>(RenderStyleVisitor<T> visitor) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited