CSSBoxShadow class

Constructors

CSSBoxShadow({Color? color, CSSLengthValue? offsetX, CSSLengthValue? offsetY, CSSLengthValue? blurRadius, CSSLengthValue? spreadRadius, bool inset = false})

Properties

blurRadius ↔ CSSLengthValue?
getter/setter pair
color ↔ Color?
getter/setter pair
computedBoxShadow → KrakenBoxShadow
no setter
hashCode → int
The hash code for this object.
no setterinherited
inset ↔ bool
getter/setter pair
offsetX ↔ CSSLengthValue?
getter/setter pair
offsetY ↔ CSSLengthValue?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spreadRadius ↔ CSSLengthValue?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseBoxShadow(String present, RenderStyle renderStyle, String propertyName) → List<CSSBoxShadow>?