CSSColor class

#123 #123456 rgb(r,g,b) rgba(r,g,b,a)

Constructors

CSSColor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Color?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertToHex(Color color) → String
isColor(String color) → bool
parseColor(String color) → Color?
resolveColor(String color, RenderStyle renderStyle, String propertyName) → Color?
tranformToDarkColor(Color color) → Color
transformToLightColor(Color color) → Color

Constants

HSL → const String
initial → const Color
INITIAL_COLOR → const String
RGB → const String
transparent → const Color