CSSLength class

Constructors

CSSLength()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isAuto(String? value) → bool
isLength(String? value) → bool
isNonNegativeLength(String? value) → bool
parseLength(String text, RenderStyle? renderStyle, [String? propertyName, Axis? axisType]) → CSSLengthValue
resolveLength(String text, RenderStyle? renderStyle, String propertyName) → CSSLengthValue?
toDouble(dynamic value) → double?
toInt(dynamic value) → int?