CSSRule class abstract

Implementers

Constructors

CSSRule()

Properties

cssText ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parentRule ↔ CSSRule?
getter/setter pair
parentStyleSheet ↔ CSSStyleSheet?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CHARSET_RULE → const int
FONT_FACE_RULE → const int
IMPORT_RULE → const int
MARGIN_RULE → const int
MEDIA_RULE → const int
NAMESPACE_RULE → const int
PAGE_RULE → const int
STYLE_RULE → const int