CSSStepCurve class

Inheritance

Constructors

CSSStepCurve(int? step, bool isStart)

Properties

flipped → Curve
Returns a new curve that is the reversed inversion of this one.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isStart → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(double t) → double
Returns the value of the curve at point t.
inherited
transformInternal(double t) → double
Returns the value of the curve at point t.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited