CSSStyleRule class

Inheritance

Constructors

CSSStyleRule(String selectorText, Map<String, String> style)

Properties

cssText ↔ String
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
parentRule ↔ CSSRule?
getter/setter pairinherited
parentStyleSheet ↔ CSSStyleSheet?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectorText → String
final
style → Map<String, String>
final
type ↔ int?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited