CSSText class

Constructors

CSSText()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

BUILTIN_FONT_PACKAGE ↔ String?
getter/setter pair
DEFAULT_FONT_FAMILY_FALLBACK ↔ List<String>?
getter/setter pair
DEFAULT_FONT_SIZE ↔ CSSLengthValue
getter/setter pair
DEFAULT_LINE_HEIGHT ↔ CSSLengthValue
getter/setter pair

Static Methods

getBackground() → Paint?
getFontPackage() → String?
getForeground() → Paint?
getLocale() → Locale?
getTextBaseLine() → TextBaseline
isValidFontStyleValue(String value) → bool
isValidFontWeightValue(String value) → bool
isValidLineHeightValue(String value) → bool
isValidTextTextDecorationLineValue(String value) → bool
isValidTextTextDecorationStyleValue(String value) → bool
parseLineClamp(String value) → int?
resolveFontFamilyFallback(String? fontFamily) → List<String>
resolveFontStyle(String? fontStyle) → FontStyle
resolveFontWeight(String? fontWeight) → FontWeight
resolveLineHeight(String value, RenderStyle renderStyle, String propertyName) → CSSLengthValue?
resolveSpacing(String spacing, RenderStyle renderStyle, String property) → CSSLengthValue
resolveTextDecorationLine(String present) → TextDecoration
In CSS2.1, text-decoration determin the type of text decoration, but in CSS3, which is text-decoration-line.
resolveTextDecorationStyle(String present) → TextDecorationStyle
resolveTextOverflow(String value) → TextOverflow
resolveTextShadow(String value, RenderStyle renderStyle, String propertyName) → List<Shadow>
resolveWhiteSpace(String value) → WhiteSpace