CSSWideKeywords enum

All of these keywords are normatively defined in the Cascade module.

Inheritance
Available extensions

Values

initial → const CSSWideKeywords

The initial keyword represents the value specified as the property’s initial value.

inherit → const CSSWideKeywords

The inherit keyword represents the computed value of the property on the element’s parent.

unset → const CSSWideKeywords

The unset keyword acts as either inherit or initial, depending on whether the property is inherited or not.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CSSWideKeywords>
A constant List of the values in this enum, in order of their declaration.