LabColor class

A color in the CIELAB color space.

The CIELAB color space contains channels for lightness l, a (red and green opponent values), and b (blue and yellow opponent values.)

Constructors

LabColor(num l, num a, num b)
A color in the CIELAB color space.
const

Properties

a → num
The red to green opponent color value.
final
b → num
The yellow to blue opponent color value.
final
hashCode → int
The hash code for this object.
no setterinherited
l → num
Lightness represents the black to white value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRgbColor() → RgbColor
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited