RenderStyle class abstract

The abstract class for render-style, declare the getter interface for all available CSS rule.

Implementers

Constructors

RenderStyle()

Properties

alignContent → AlignContent
no setter
alignItems → AlignItems
no setter
alignSelf → AlignSelf
no setter
backgroundColor → Color?
no setter
backgroundImage → CSSBackgroundImage?
no setter
backgroundPositionX → CSSBackgroundPosition
no setter
backgroundPositionY → CSSBackgroundPosition
no setter
backgroundRepeat → ImageRepeat
no setter
border → EdgeInsets
no setter
borderBottomColor → Color
no setter
borderBottomLeftRadius → CSSBorderRadius
no setter
borderBottomRightRadius → CSSBorderRadius
no setter
borderBottomStyle → BorderStyle
no setter
borderBottomWidth → CSSLengthValue?
no setter
borderBoxHeight → double?
no setter
borderBoxLogicalHeight → double?
no setter
borderBoxLogicalWidth → double?
no setter
borderBoxWidth → double?
no setter
borderLeftColor → Color
no setter
borderLeftStyle → BorderStyle
no setter
borderLeftWidth → CSSLengthValue?
no setter
borderRadius → List<Radius>?
no setter
borderRightColor → Color
no setter
borderRightStyle → BorderStyle
no setter
borderRightWidth → CSSLengthValue?
no setter
borderSides → List<BorderSide>?
no setter
borderTopColor → Color
no setter
borderTopLeftRadius → CSSBorderRadius
no setter
borderTopRightRadius → CSSBorderRadius
no setter
borderTopStyle → BorderStyle
no setter
borderTopWidth → CSSLengthValue?
no setter
bottom → CSSLengthValue
no setter
color → Color
no setter
colorFilter → ColorFilter?
no setter
contentBoxHeight → double?
no setter
contentBoxLogicalHeight → double?
no setter
contentBoxLogicalWidth → double?
no setter
contentBoxWidth → double?
no setter
contentMaxConstraintsWidth → double
no setter
contentVisibility → ContentVisibility?
no setter
currentColor → Color
no setter
display → CSSDisplay
no setter
effectiveBorderBottomWidth → CSSLengthValue
no setter
effectiveBorderLeftWidth → CSSLengthValue
no setter
effectiveBorderRightWidth → CSSLengthValue
no setter
effectiveBorderTopWidth → CSSLengthValue
no setter
effectiveDisplay → CSSDisplay
no setter
effectiveOverflowX → CSSOverflowType
no setter
effectiveOverflowY → CSSOverflowType
no setter
filter → List<CSSFunctionalNotation>?
no setter
flexBasis → CSSLengthValue?
no setter
flexDirection → FlexDirection
no setter
flexGrow → double
no setter
flexShrink → double
no setter
flexWrap → FlexWrap
no setter
fontFamily → List<String>?
no setter
fontSize → CSSLengthValue
no setter
fontStyle → FontStyle
no setter
fontWeight → FontWeight
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → CSSLengthValue
no setter
imageFilter → ImageFilter?
no setter
intrinsicHeight → double
no setter
intrinsicRatio → double?
no setter
intrinsicWidth → double
no setter
isHeightStretch → bool
no setter
justifyContent → JustifyContent
no setter
left → CSSLengthValue
no setter
letterSpacing → CSSLengthValue?
no setter
lineClamp → int?
no setter
lineHeight → CSSLengthValue
no setter
margin → EdgeInsets
no setter
marginBottom → CSSLengthValue
no setter
marginLeft → CSSLengthValue
no setter
marginRight → CSSLengthValue
no setter
marginTop → CSSLengthValue
no setter
maxHeight → CSSLengthValue
no setter
maxWidth → CSSLengthValue
no setter
minHeight → CSSLengthValue
no setter
minWidth → CSSLengthValue
no setter
objectFit → BoxFit
no setter
objectPosition → Alignment
no setter
opacity → double
no setter
overflowX → CSSOverflowType
no setter
overflowY → CSSOverflowType
no setter
padding → EdgeInsets
no setter
paddingBottom → CSSLengthValue
no setter
paddingBoxHeight → double?
no setter
paddingBoxLogicalHeight → double?
no setter
paddingBoxLogicalWidth → double?
no setter
paddingBoxWidth → double?
no setter
paddingLeft → CSSLengthValue
no setter
paddingRight → CSSLengthValue
no setter
paddingTop → CSSLengthValue
no setter
parent → RenderStyle?
no setter
position → CSSPositionType
no setter
renderBoxModel → RenderBoxModel?
no setter
no setter
rootFontSize → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<KrakenBoxShadow>?
no setter
sliverDirection → Axis
no setter
target → Element
no setter
textAlign → TextAlign
no setter
textOverflow → TextOverflow
no setter
textShadow → List<Shadow>?
no setter
top → CSSLengthValue
no setter
transitionDelay → List<String>
no setter
transitionDuration → List<String>
no setter
transitionProperty → List<String>
no setter
transitionTimingFunction → List<String>
no setter
verticalAlign → VerticalAlign
no setter
viewportSize → Size
no setter
visibility → Visibility
no setter
whiteSpace → WhiteSpace
no setter
width → CSSLengthValue
no setter
wordSpacing → CSSLengthValue?
no setter
zIndex → int?
no setter

Methods

addColorRelativeProperty(String propertyName) → void
addFontRelativeProperty(String propertyName) → void
addRootFontRelativeProperty(String propertyName) → void
getCSSVariable(String identifier, String propertyName) → String?
getHeightByIntrinsicRatio() → double
getProperty(String key) → dynamic
getWidthByIntrinsicRatio() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAnimationProperty(String propertyName) → String?
resolveValue(String property, String present) → dynamic
Resolve the style value.
setCSSVariable(String identifier, String value) → void
toString() → String
A string representation of this object.
inherited
visitChildren<T extends RenderStyle>(RenderStyleVisitor<T> visitor) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited