RgbColor class

Constructors

RgbColor(num r, num g, num b)
Creates a Color using a vector describing its red, green, and blue values.
const

Properties

b → num
final
g → num
final
hashCode → int
The hash code for this object.
no setterinherited
r → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLabColor() → LabColor
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited