VerticalAlign enum

Sets vertical alignment of an inline, inline-block

Inheritance
Available extensions

Values

baseline → const VerticalAlign

Aligns the baseline of the element with the baseline of its parent.

top → const VerticalAlign

Aligns the top of the element and its descendants with the top of the entire line.

bottom → const VerticalAlign

Aligns the bottom of the element and its descendants with the bottom of the entire line.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<VerticalAlign>
A constant List of the values in this enum, in order of their declaration.