BoxModel class

Inheritance

Constructors

BoxModel({List<double>? content, List<double>? padding, List<double>? border, List<double>? margin, int? width, int? height})

Properties

border ↔ List<double>?
getter/setter pair
content ↔ List<double>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
getter/setter pair
margin ↔ List<double>?
getter/setter pair
padding ↔ List<double>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited