CSSStyle class

Inheritance

Constructors

CSSStyle({int? styleSheetId, required List<CSSProperty> cssProperties, required List<ShorthandEntry> shorthandEntries, String? cssText, SourceRange? range})

Properties

cssProperties ↔ List<CSSProperty>
getter/setter pair
cssText ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
range ↔ SourceRange?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shorthandEntries ↔ List<ShorthandEntry>
getter/setter pair
styleSheetId ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited