ChromeDevToolsService class

Inheritance

Constructors

ChromeDevToolsService()

Properties

controller → KrakenController?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isolateServerPort → SendPort?
no setter
isReloading → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiInspector → UIInspector?
no setter

Methods

didReload() → void
override
dispose() → void
override
init(KrakenController controller) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
willReload() → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

prevDevTools ↔ ChromeDevToolsService?
Design prevDevTool for reload page, do not use it in any other place. More detail see InspectPageModule.handleReloadPage.
getter/setter pair

Static Methods

getDevToolOfContextId(int contextId) → ChromeDevToolsService?