ComputedStyle class

Inheritance

Constructors

ComputedStyle({required List<CSSComputedStyleProperty> computedStyle})

Properties

computedStyle ↔ List<CSSComputedStyleProperty>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited