Frame class

Inheritance

Constructors

Frame(String id, String loaderId, String url, String domainAndRegistry, String securityOrigin, String mimeType, String secureContextType, String crossOriginIsolatedContextType, List<String> gatedAPIFeatures, {String? parentId, String? name, String? urlFragment, String? unreachableUrl, String? AdFrameType})

Properties

AdFrameType ↔ String?
getter/setter pair
crossOriginIsolatedContextType → String
final
domainAndRegistry → String
final
gatedAPIFeatures → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
loaderId → String
final
mimeType → String
final
name ↔ String?
getter/setter pair
parentId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureContextType → String
final
securityOrigin → String
final
unreachableUrl ↔ String?
getter/setter pair
url → String
final
urlFragment ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited