FrameResource class

Inheritance

Constructors

FrameResource(String url, String type, String mimeType, {int? lastModified, int? contentSize, bool? failed, bool? canceled})

Properties

canceled ↔ bool?
getter/setter pair
contentSize ↔ int?
getter/setter pair
failed ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModified ↔ int?
getter/setter pair
mimeType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited