FrameResourceTree class

Inheritance

Constructors

FrameResourceTree(Frame frame, List<FrameResource> resources, {List<FrameResourceTree>? childFrames})

Properties

childFrames ↔ List<FrameResourceTree>?
getter/setter pair
frame → Frame
final
hashCode → int
The hash code for this object.
no setterinherited
resources → List<FrameResource>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited