InspectDOMModule class

Inheritance

Constructors

InspectDOMModule(ChromeDevToolsService devtoolsService)

Properties

devtoolsService → ChromeDevToolsService
finalinherited
document → Document
no setter
hashCode → int
The hash code for this object.
no setterinherited
inspectedNode ↔ Node?
Enables console to refer to the node with given id via $x (see Command Line API for more details $x functions).
getter/setter pair
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(int? id, String method, Map<String, dynamic>? params) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onGetBoxModel(int? id, Map<String, dynamic> params) → void
onGetDocument(int? id, String method, Map<String, dynamic>? params) → void
https://chromedevtools.github.io/devtools-protocol/tot/DOM/#method-getDocument
onGetNodeForLocation(int? id, Map<String, dynamic> params) → void
onSetInspectedNode(int? id, Map<String, dynamic> params) → void
receiveFromFrontend(int? id, String method, Map<String, dynamic>? params) → void
sendEventToFrontend(InspectorEvent event) → void
inherited
sendToFrontend(int? id, JSONEncodable? result) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited