IsolateInspectorServer class

Constructors

IsolateInspectorServer(int port, String address, String bundleURL)

Properties

address → String
final
bundleURL → String
final
connected → bool
InspectServer has connected frontend.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isolateToMainStream → SendPort?
no setter
moduleRegistrar → Map<String, IsolateInspectorModule>
final
nativeInspectorMessageHandler ↔ NativeInspectorMessageHandler?
getter/setter pair
onFrontendMessage ↔ MessageCallback?
getter/setter pair
onStarted ↔ VoidCallback?
getter/setter pair
port ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
messageRouter(int? id, String module, String method, Map<String, dynamic>? params) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onHTTPRequest(HttpRequest request) → Future<void>
onRequestActivate(HttpRequest request) → void
onRequestClose(HttpRequest request) → void
onRequestFallback(HttpRequest request) → void
onRequestList(HttpRequest request) → void
onRequestNew(HttpRequest request) → void
onRequestProtocol(HttpRequest request) → void
onRequestVersion(HttpRequest request) → void
onWebSocketRequest(dynamic message) → void
registerModule(IsolateInspectorModule module) → void
sendEventToFrontend(InspectorEvent event) → void
sendRawJSONToFrontend(String message) → void
sendToFrontend(int? id, Map? result) → void
start() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited