LogEntryEvent class

Inheritance

Constructors

LogEntryEvent({required String level, required String text, String source = 'javascript', String? url})

Properties

hashCode → int
The hash code for this object.
no setterinherited
level ↔ String
getter/setter pair
method → String
no setteroverride
params → JSONEncodable?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String
getter/setter pair
text ↔ String
getter/setter pair
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited