MatchedStyles class

Inheritance

Constructors

MatchedStyles({CSSStyle? inlineStyle, CSSStyle? attributesStyle, List<RuleMatch>? matchedCSSRules, List<PseudoElementMatches>? pseudoElements, List<InheritedStyleEntry>? inherited, List<CSSKeyframesRule>? cssKeyframesRules})

Properties

attributesStyle ↔ CSSStyle?
getter/setter pair
cssKeyframesRules ↔ List<CSSKeyframesRule>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inherited ↔ List<InheritedStyleEntry>?
getter/setter pair
inlineStyle ↔ CSSStyle?
getter/setter pair
matchedCSSRules ↔ List<RuleMatch>?
getter/setter pair
pseudoElements ↔ List<PseudoElementMatches>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited