NetworkRequestWillBeSentEvent class

Inheritance

Constructors

NetworkRequestWillBeSentEvent({required String requestId, required String loaderId, required String requestMethod, required String url, required Map<String, List<String>> headers, required int timestamp})

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, List<String>>
final
loaderId → String
final
method → String
no setteroverride
params → JSONEncodable?
no setteroverride
requestId → String
final
requestMethod → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited