NetworkResponseReceivedEvent class

Inheritance

Constructors

NetworkResponseReceivedEvent({required String requestId, required String loaderId, required String url, required Map<String, List<String>> headers, required int status, required String statusText, required String mimeType, required String remoteIPAddress, required int remotePort, required bool fromDiskCache, required int encodedDataLength, required String protocol, required String type, required int timestamp})

Properties

encodedDataLength → int
final
fromDiskCache → bool
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, List<String>>
final
loaderId → String
final
method → String
no setteroverride
mimeType → String
final
params → JSONEncodable?
no setteroverride
protocol → String
final
remoteIPAddress → String
final
remotePort → int
final
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
final
statusText → String
final
timestamp → int
final
type → String
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited