ScreenCastFrame class

Implemented types
Annotations

Constructors

ScreenCastFrame(String data, ScreencastFrameMetadata metadata, int sessionId)

Properties

data → String
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → ScreencastFrameMetadata
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited