ScreencastFrameMetadata class

Implemented types
Annotations

Constructors

ScreencastFrameMetadata(num offsetTop, num pageScaleFactor, num deviceWidth, num deviceHeight, num scrollOffsetX, num scrollOffsetY, {num? timestamp})

Properties

deviceHeight → num
final
deviceWidth → num
final
hashCode → int
The hash code for this object.
no setterinherited
offsetTop → num
final
pageScaleFactor → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollOffsetX → num
final
scrollOffsetY → num
final
timestamp → num?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited