CloseEvent class

Inheritance

Constructors

CloseEvent(int code, String reason, bool wasClean)

Properties

bubbles ↔ bool
getter/setter pairinherited
cancelable ↔ bool
getter/setter pairinherited
code → int
An unsigned short containing the close code sent by the server
final
currentTarget ↔ EventTarget?
getter/setter pairinherited
defaultPrevented ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
propagationStopped ↔ bool
getter/setter pairinherited
reason → String
Indicating the reason the server closed the connection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ EventTarget?
getter/setter pairinherited
timeStamp ↔ int
getter/setter pairinherited
type ↔ String
getter/setter pairinherited
wasClean → bool
Indicates whether or not the connection was cleanly closed
final

Methods

canBubble() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toRaw([int methodLength = 0]) → Pointer<RawNativeCloseEvent>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited