Document class

Inheritance

Constructors

Document(dynamic context, {required KrakenController controller, required RenderViewportBox viewport, GestureListener? gestureListener, WidgetDelegate? widgetDelegate})

Properties

adoptedStyleSheets ↔ List<CSSStyleSheet>
getter/setter pair
childNodes ↔ List<Node>
getter/setter pairinherited
children → List<Element>
no setterinherited
contextId → int?
no setterinherited
controller → KrakenController
final
defaultView → Window
no setter
disposed → bool
no setterinherited
documentElement ↔ Element?
getter/setter pair
eventPath → List<EventTarget>
no setterinherited
firstChild → Node
no setterinherited
flutterElement ↔ KrakenElementToFlutterElementAdaptor?
getter/setter pairinherited
flutterWidget ↔ KrakenElementToWidgetAdaptor?
getter/setter pairinherited
focusedElement ↔ Element?
getter/setter pair
gestureListener ↔ GestureListener?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isConnected → bool
no setterinherited
isRendererAttached → bool
no setterinherited
lastChild → Node
no setterinherited
nextSibling → Node?
no setterinherited
nodeName → String
no setteroverride
nodeType ↔ NodeType
getter/setter pairinherited
ownerDocument ↔ Document
getter/setter pairinherited-setteroverride-getter
parentElement → Element?
The Node.parentElement read-only property returns the DOM node's parent Element, or null if the node either has no parent, or its parent isn't a DOM Element.
no setterinherited
parentEventTarget → EventTarget?
no setteroverride
parentNode ↔ Node?
The Node.parentNode read-only property returns the parent of the specified node in the DOM tree.
getter/setter pairinherited
pointer → dynamic
no setterinherited
previousSibling → Node?
no setterinherited
renderer → RenderBox?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleSheets → List<CSSStyleSheet>
final
viewport → RenderViewportBox?
no setter
widgetDelegate ↔ WidgetDelegate?
getter/setter pair

Methods

addEventListener(String eventType, EventHandler eventHandler) → void
inherited
addStyleSheet(CSSStyleSheet sheet) → void
appendChild(Node child) → Node
override
attachTo(Element parent, {RenderBox? after}) → void
Attach a renderObject to parent.
inherited
childrenChanged() → void
inherited
connectedCallback() → void
inherited
contains(Node child) → bool
inherited
createComment([BindingContext? context]) → Comment
createDocumentFragment([BindingContext? context]) → DocumentFragment
createElement(String type, [BindingContext? context]) → Element
createRenderer() → RenderBox
Creates an instance of the RenderObject class that this RenderObjectNode represents, using the configuration described by this RenderObjectNode.
inherited
createTextNode(String data, [BindingContext? context]) → TextNode
didAttachRenderer() → void
inherited
didDetachRenderer() → void
inherited
disconnectedCallback() → void
inherited
dispatchEvent(Event event) → void
inherited
dispose() → void
Release any resources held by this node.
override
ensureChildAttached() → void
Ensure child and child's child render object is attached.
inherited
getBindingProperty(String key) → dynamic
inherited
getEventHandlers() → Map<String, List<EventHandler>>
inherited
hasEventListener(String type) → bool
inherited
insertBefore(Node child, Node referenceNode) → Node
override
invokeBindingMethod(String method, List args) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recalculateDocumentStyle() → void
removeChild(Node child) → Node
override
removeEventListener(String eventType, EventHandler eventHandler) → void
inherited
removeStyleSheet(CSSStyleSheet sheet) → void
replaceChild(Node newNode, Node oldNode) → Node?
override
setBindingProperty(String key, dynamic value) → void
inherited
toString() → String
A string representation of this object.
inherited
unmountRenderObject({bool deep = false}) → void
Unmount referenced render object.
inherited
willAttachRenderer() → void
The renderObject will be / has been insert into parent. You can apply properties to renderObject.
inherited
willDetachRenderer() → void
A render object previously associated with this Node will be / has been removed from the tree. The given RenderObject will be of the same type as returned by this object's createRenderer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited