EditableTextDelegate class

Implemented types

Constructors

EditableTextDelegate(TextFormControlElement _textFormControlElement)

Properties

copyEnabled → bool
Whether copy is enabled.
no setteroverride
cutEnabled → bool
Whether cut is enabled.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
liveTextInputEnabled → bool
Whether Live Text input is enabled.
no setterinherited
lookUpEnabled → bool
Whether look up is enabled.
no setterinherited
pasteEnabled → bool
Whether paste is enabled.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchWebEnabled → bool
Whether search web is enabled.
no setterinherited
selectAllEnabled → bool
Whether select all is enabled.
no setteroverride
shareEnabled → bool
Whether share is enabled.
no setterinherited
textEditingValue ↔ TextEditingValue
Gets the current text input.
getter/setter pairoverride-getter

Methods

bringIntoView(TextPosition position) → void
Brings the provided TextPosition into the visible area of the text input.
override
copySelection(SelectionChangedCause cause) → void
Copy current selection to Clipboard.
override
cutSelection(SelectionChangedCause cause) → void
Cut current selection to Clipboard.
override
hideToolbar([bool hideHandles = true]) → void
Hides the text selection toolbar.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pasteText(SelectionChangedCause cause) → Future<void>
Paste text from Clipboard.
override
selectAll(SelectionChangedCause cause) → void
Set the current selection to contain the entire text value.
override
showToolbar() → bool
Shows the selection toolbar at the location of the current cursor.
toggleToolbar() → void
Toggles the visibility of the toolbar.
toString() → String
A string representation of this object.
inherited
userUpdateTextEditingValue(TextEditingValue value, SelectionChangedCause cause) → void
Indicates that the user has requested the delegate to replace its current text editing state with value.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited