GestureEventInit class

Inheritance

Constructors

GestureEventInit({bool bubbles = false, bool cancelable = false, String state = '', String direction = '', double rotation = 0.0, double deltaX = 0.0, double deltaY = 0.0, double velocityX = 0.0, double velocityY = 0.0, double scale = 0.0})

Properties

bubbles → bool
finalinherited
cancelable → bool
finalinherited
deltaX → double
final
deltaY → double
final
direction → String
final
hashCode → int
The hash code for this object.
no setterinherited
rotation → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
state → String
final
velocityX → double
final
velocityY → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited