MouseEventInit class

Inheritance

Constructors

MouseEventInit({bool bubbles = false, bool cancelable = false, double clientX = 0.0, double clientY = 0.0, double offsetX = 0.0, double offsetY = 0.0})

Properties

bubbles → bool
finalinherited
cancelable → bool
finalinherited
clientX → double
final
clientY → double
final
hashCode → int
The hash code for this object.
no setterinherited
offsetX → double
final
offsetY → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited