TextFormControlElement class

Inheritance
Implemented types
Implementers

Constructors

TextFormControlElement(dynamic context, {bool isMultiline = false, Map<String, dynamic>? defaultStyle, bool? isReplacedElement})

Properties

accept ↔ String
getter/setter pair
attributes → Map<String, String>
finalinherited
autocomplete ↔ String
getter/setter pair
autoCorrect ↔ bool
getter/setter pair
autofocus ↔ bool
getter/setter pair
avgCharHeight → double
no setter
avgCharSize → Size
no setter
avgCharWidth → double
no setter
boundingClientRect → BoundingClientRect
no setterinherited
checked ↔ bool
getter/setter pair
childNodes ↔ List<Node>
getter/setter pairinherited
children → List<Element>
no setterinherited
classList → List<String>
no setterinherited
className ↔ String
getter/setter pairinherited
clientHeight → int
no setterinherited
clientLeft → int
no setterinherited
clientTop → int
no setterinherited
clientWidth → int
no setterinherited
contextId → int?
no setterinherited
currentAutofillScope → AutofillScope
The AutofillScope this TextInputClient belongs to, if any.
no setteroverride
currentTextEditingValue → TextEditingValue
The current state of the TextEditingValue held by this client.
no setteroverride
cursorColor ↔ Color
getter/setter pair
cursorRadius ↔ Radius
getter/setter pair
defaultStyle ↔ Map<String, dynamic>?
getter/setter pair
defaultValue ↔ String
getter/setter pair
disabled ↔ bool
getter/setter pair
disposed → bool
no setterinherited
eventPath → List<EventTarget>
no setterinherited
firstChild → Node
no setterinherited
flutterElement ↔ KrakenElementToFlutterElementAdaptor?
getter/setter pairinherited
flutterWidget ↔ KrakenElementToWidgetAdaptor?
getter/setter pairinherited
forceToRepaintBoundary ← bool
no getterinherited
hasDirtyValue ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
inlineStyle → Map<String, dynamic>
The inline style is a map of style property name to style property value.
finalinherited
inputMode ↔ String
getter/setter pair
isConnected → bool
no setterinherited
isMultiline ↔ bool
getter/setter pair
isRendererAttached → bool
no setterinherited
isRepaintBoundary → bool
Whether should as a repaintBoundary for this element when style changed
no setterinherited
isReplacedElement ↔ bool?
getter/setter pair
lastChild → Node
no setterinherited
max ↔ String
getter/setter pair
maxLength ↔ int
getter/setter pair
min ↔ String
getter/setter pair
minLength ↔ int
getter/setter pair
multiple ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
nextSibling → Node?
no setterinherited
nodeName → String
no setterinherited
nodeType ↔ NodeType
getter/setter pairinherited
obscureText ↔ bool
getter/setter pair
offsetHeight → int
no setterinherited
offsetLeft → int
no setterinherited
offsetParent → Element?
no setterinherited
offsetTop → int
no setterinherited
offsetWidth → int
no setterinherited
ownerDocument ↔ Document
getter/setter pairinherited
parentElement → Element?
The Node.parentElement read-only property returns the DOM node's parent Element, or null if the node either has no parent, or its parent isn't a DOM Element.
no setterinherited
parentEventTarget → EventTarget?
no setterinherited
parentNode ↔ Node?
The Node.parentNode read-only property returns the parent of the specified node in the DOM tree.
getter/setter pairinherited
pattern ↔ String
getter/setter pair
placeholder ↔ String
getter/setter pair
placeholderText → String
no setter
placeholderTextSpan → TextSpan
no setter
pointer → dynamic
no setterinherited
previousSibling → Node?
no setterinherited
readOnly ↔ bool
getter/setter pair
renderBoxModel ↔ RenderBoxModel?
getter/setter pairinherited
renderEditable ↔ RenderEditable?
getter/setter pair
renderer → RenderBox?
no setterinherited
renderStyle ↔ CSSRenderStyle
getter/setter pairinherited
renderTextControlLeaderLayer ↔ RenderTextControlLeaderLayer?
getter/setter pair
required ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollHeight → int
no setterinherited
scrollLeft ↔ double
getter/setter pairinherited
scrollOffset ↔ ViewportOffset
getter/setter pair
scrollTop ↔ double
getter/setter pairinherited
scrollWidth → int
no setterinherited
selectionColor ↔ Color
getter/setter pair
step ↔ String
getter/setter pair
style ↔ CSSStyleDeclaration
The style of the element, not inline style.
getter/setter pairinherited
tagName ↔ String
getter/setter pairinherited
textEditingActionTarget ↔ Object?
getter/setter pair
textInputType ↔ TextInputType
getter/setter pair
type ↔ String
getter/setter pair
value ↔ String
getter/setter pair
width ↔ int
getter/setter pair

Methods

activeTextInput() → void
addChild(RenderBox child) → void
inherited
addEventListener(String eventType, EventHandler handler) → void
inherited
addToContainingBlock() → void
inherited
appendChild(Node child) → Node
inherited
attachTo(Node parent, {RenderBox? after}) → void
Attach a renderObject to parent.
inherited
beginBatchEdit() → void
Begins a new batch edit, within which new updates made to the text editing value will not be sent to the platform text input plugin.
blur() → void
Moves the focus to the viewport. Use of this method is discouraged; if you want to focus the viewport, call the focus() method on the Document's document element. https://html.spec.whatwg.org/multipage/interaction.html#dom-blur
override
blurTextFormControl() → void
childrenChanged() → void
inherited
clearEventResponder(RenderEventListenerMixin renderBox) → void
inherited
click() → void
inherited
connectedCallback() → void
inherited
connectionClosed() → void
Platform notified framework of closed connection.
override
contains(Node child) → bool
inherited
createRenderBox() → RenderTextControlLeaderLayer
createRenderEditable() → RenderEditable
createRenderer() → RenderBox
Creates an instance of the RenderObject class that this RenderObjectNode represents, using the configuration described by this RenderObjectNode.
inherited
createScrollingContentLayout() → RenderLayoutBox
inherited
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
override
deactiveTextInput() → void
debugHideHighlight() → void
inherited
debugHighlight() → void
inherited
didAttachRenderer() → void
override
didChangeInputControl(TextInputControl? oldControl, TextInputControl? newControl) → void
The framework calls this method to notify that the text input control has been changed.
inherited
didDetachRenderer() → void
override
disconnectedCallback() → void
inherited
dispatchEvent(Event event) → void
inherited
dispose() → void
Release any resources held by this node.
override
disposeScrollable() → void
inherited
endBatchEdit() → void
Ends the current batch edit started by the last call to beginBatchEdit, and send currentTextEditingValue to the text input plugin if needed.
ensureChildAttached() → void
Ensure child and child's child render object is attached.
inherited
ensureEventResponderBound() → void
inherited
findDirectPositionAbsoluteChildren() → List<Element>
inherited
findNestedPositionAbsoluteChildren() → List<Element>
inherited
flushLayout() → void
inherited
focus() → void
Moves the focus to the element. https://html.spec.whatwg.org/multipage/interaction.html#dom-focus
override
focusTextFormControl() → void
getAttribute(String qualifiedName) → String?
inherited
getBindingProperty(String key) → dynamic
inherited
getBoundingClientRect() → BoundingClientRect
inherited
getContainingBlockRenderBox() → RenderBox?
inherited
getEventHandlers() → Map<String, List<EventHandler>>
inherited
getEventTarget() → EventTarget
inherited
getTextSize() → Size
handleAppear() → void
inherited
handleDisappear() → void
inherited
handleIntersectionChange(IntersectionObserverEntry entry) → void
inherited
hasAttribute(String qualifiedName) → bool
inherited
hasEventListener(String type) → bool
inherited
insertBefore(Node child, Node referenceNode) → Node
inherited
insertContent(KeyboardInsertedContent content) → void
Notify client about new content insertion from Android keyboard.
inherited
insertTextPlaceholder(Size size) → void
Requests that the client add a text placeholder to reserve visual space in the text.
inherited
internalSetAttribute(String qualifiedName, String value) → void
inherited
invokeBindingMethod(String method, List args) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFocusReceived() → bool
Notifies the client that the platform moved focus back to this input.
inherited
performAction(TextInputAction action) → void
Requests that this client perform the given action.
override
performPrivateCommand(String action, Map<String, dynamic> data) → void
Request from the input method that this client perform the given private command.
override
performSelector(String selectorName) → void
Performs the specified MacOS-specific selector from the NSStandardKeyBindingResponding protocol or user-specified selector from DefaultKeyBinding.Dict.
inherited
recalculateNestedStyle() → void
inherited
recalculateStyle() → void
inherited
removeAttribute(String qualifiedName) → void
inherited
removeChild(Node child) → Node
inherited
removeEventListener(String eventType, EventHandler handler) → void
inherited
removeTextPlaceholder() → void
Requests that the client remove the text placeholder.
inherited
replaceChild(Node newNode, Node oldNode) → Node?
inherited
requestKeyboard() → void
sanitizeValue(String? text) → String
scroll(double x, double y) → void
inherited
scrollBy(double x, double y) → void
inherited
scrollingContentBoxStyleListener(String property, String? original, String present) → void
inherited
scrollTo(double x, double y) → void
inherited
scrollToCaret() → void
setAttribute(String qualifiedName, String value) → void
inherited
setBindingProperty(String key, dynamic value) → void
inherited
setInlineStyle(String property, String value) → void
inherited
setRenderStyle(String property, String present) → void
inherited
setRenderStyleProperty(String name, dynamic value) → void
inherited
setStyle(String property, dynamic value) → void
inherited
setValue(String? text) → String
showAutocorrectionPromptRect(int start, int end) → void
Requests that this client display a prompt rectangle for the given text range, to indicate the range of text that will be changed by a pending autocorrection.
override
showToolbar() → void
Requests that the client show the editing toolbar, for example when the platform changes the selection through a non-flutter method such as scribble.
inherited
toBlob({double? devicePixelRatio}) → Future<Uint8List>
inherited
toString() → String
A string representation of this object.
inherited
unmountRenderObject({bool deep = false}) → void
Unmount renderBoxModel.
inherited
updateEditingValue(TextEditingValue value) → void
Requests that this client update its editing state to the given value.
override
updateFloatingCursor(RawFloatingCursorPoint point) → void
Updates the floating cursor position and state.
override
updateOverflowRenderBox() → void
inherited
updateRenderBoxModelWithOverflowX(ScrollListener scrollListener) → void
inherited
updateRenderBoxModelWithOverflowY(ScrollListener scrollListener) → void
inherited
updateScrollingContentBox() → void
inherited
willAttachRenderer() → void
The renderObject will be / has been insert into parent. You can apply properties to renderObject.
override
willDetachRenderer() → void
A render object previously associated with this Node will be / has been removed from the tree. The given RenderObject will be of the same type as returned by this object's createRenderer.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

obscuringCharacter ↔ String
getter/setter pair