Window class

Inheritance

Constructors

Window(BindingContext? context, Document document)

Properties

colorScheme → String
no setter
contextId → int?
no setterinherited
devicePixelRatio → double
no setter
disposed → bool
no setterinherited
document → Document
final
eventPath → List<EventTarget>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
innerHeight → int
no setter
innerWidth → int
no setter
parentEventTarget → EventTarget?
no setteroverride
pointer → dynamic
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen → Screen
final
scrollX → double
no setter
scrollY → double
no setter

Methods

addEventListener(String eventType, EventHandler handler) → void
override
dispatchEvent(Event event) → void
override
dispose() → void
inherited
focus() → void
Moves the focus to the window's browsing context, if any. https://html.spec.whatwg.org/multipage/interaction.html#dom-window-focus
getBindingProperty(String key) → dynamic
override
getEventHandlers() → Map<String, List<EventHandler>>
inherited
hasEventListener(String type) → bool
inherited
invokeBindingMethod(String method, List args) → dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String url) → void
removeEventListener(String eventType, EventHandler handler) → void
override
scrollBy(double x, double y) → void
scrollTo(double x, double y) → void
setBindingProperty(String key, dynamic value) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited