AssetsBundle class

Inheritance

Constructors

AssetsBundle(String url)

Properties

contentType ↔ ContentType
getter/setter pairinherited
data ↔ Uint8List?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isBytecode → bool
no setterinherited
isCSS → bool
no setterinherited
isHTML → bool
no setterinherited
isJavascript → bool
no setterinherited
isResolved → bool
no setterinherited
resolvedUri → Uri?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
finalinherited

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(int? contextId) → Future<KrakenBundle>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getAssetName(Uri assetUri) → String
Get flutter asset name from uri scheme asset. eg: assets:///foo/bar.html -> foo/bar.html assets:foo/bar.html -> foo/bar.html