AsyncStorageModule class

Inheritance

Constructors

AsyncStorageModule(ModuleManager? moduleManager)

Properties

hashCode → int
The hash code for this object.
no setterinherited
moduleManager → ModuleManager?
finalinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
invoke(String method, dynamic params, InvokeModuleCallback callback) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clear() → Future<bool>
getAllKeys() → Future<Set<String>>
getItem(String key) → Future<String?>
length() → Future<int>
removeItem(String key) → Future<bool>
setItem(String key, String value) → Future<bool>