HttpCacheController class

Constructors

HttpCacheController.instance(String origin)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCacheObject(Uri uri) → Future<HttpCacheObject>
interceptResponse(HttpClientRequest request, HttpClientResponse response, HttpCacheObject cacheObject) → Future<HttpClientResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putObject(Uri uri, HttpCacheObject cacheObject) → void
removeObject(Uri uri) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

mode ↔ HttpCacheMode
getter/setter pair

Static Methods

getCacheDirectory() → Future<Directory>