FileImageProviderParams class

Inheritance

Constructors

FileImageProviderParams(File file, {int? cachedWidth, int? cachedHeight, BoxFit objectFit = BoxFit.fill})

Properties

cachedHeight ↔ int?
getter/setter pairinherited
cachedWidth ↔ int?
getter/setter pairinherited
file ↔ File
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectFit ↔ BoxFit
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited